@@ -12,59 +12,59 @@ FunctionParameterTypeFactory <- function() {
                        error = 'error management',
                        user_defined = 'user defined')
 
-  isWarning <- function(x_) 'warning' %in% class(x_)
-  isError <- function(x_) 'error' %in% class(x_)
+  isWarning <- function(o_1l_) 'warning' %in% class(o_1l_)
+  isError <- function(o_1l_) 'error' %in% class(o_1l_)
 
-  isPureBoolean <- function(o_1_) {
-    if (!is.logical(o_1_)) return(FALSE)
-    if (length(o_1_) == 0) return(TRUE)
-    all(is.na(o_1_) == FALSE)
+  isPureBoolean <- function(o_1l_) {
+    if (!is.logical(o_1l_)) return(FALSE)
+    if (length(o_1l_) == 0) return(TRUE)
+    all(is.na(o_1l_) == FALSE)
   }
 
-  isPureComplex <- function(o_1_) {
-    if (!is.complex(o_1_)) return(FALSE)
-    if (length(o_1_) == 0) return(TRUE)
-    all(is.na(o_1_) == FALSE) && all(is.infinite(o_1_) == FALSE)
+  isPureComplex <- function(o_1l_) {
+    if (!is.complex(o_1l_)) return(FALSE)
+    if (length(o_1l_) == 0) return(TRUE)
+    all(is.na(o_1l_) == FALSE) && all(is.infinite(o_1l_) == FALSE)
   }
 
-  isPureInteger <- function(o_1_) {
-    if (!is.numeric(o_1_)) return(FALSE)
-    if (length(o_1_) == 0) return(typeof(o_1_) == 'integer')
-    all(is.double(o_1_) == FALSE)
+  isPureInteger <- function(o_1l_) {
+    if (!is.numeric(o_1l_)) return(FALSE)
+    if (length(o_1l_) == 0) return(typeof(o_1l_) == 'integer')
+    all(is.double(o_1l_) == FALSE)
   }
 
-  isPureMathInteger <- function(o_1_) {
-    if (!isPureInteger(o_1_)) return(FALSE)
-    if (length(o_1_) == 0) return(TRUE)
-    !is.na(o_1_[1]) && !is.infinite(o_1_[1])
+  isPureMathInteger <- function(o_1l_) {
+    if (!isPureInteger(o_1l_)) return(FALSE)
+    if (length(o_1l_) == 0) return(TRUE)
+    !is.na(o_1l_[1]) && !is.infinite(o_1l_[1])
   }
 
-  isPureReal <- function(o_1_) {
-    if (!is.double(o_1_)) return(FALSE)
-    if (length(o_1_) == 0) return(TRUE)
-    all(is.na(o_1_[1]) == FALSE) && all(is.infinite(o_1_) == FALSE)
+  isPureReal <- function(o_1l_) {
+    if (!is.double(o_1l_)) return(FALSE)
+    if (length(o_1l_) == 0) return(TRUE)
+    all(is.na(o_1l_[1]) == FALSE) && all(is.infinite(o_1l_) == FALSE)
   }
 
-  isPositiveReal <- function(o_1_) isPureReal(o_1_) && all(o_1_ >= 0.0)
+  isPositiveReal <- function(o_1l_) isPureReal(o_1l_) && all(o_1l_ >= 0.0)
 
-  isNegativeReal <- function(o_1_) isPureReal(o_1_) && all(o_1_ <= 0.0)
+  isNegativeReal <- function(o_1l_) isPureReal(o_1l_) && all(o_1l_ <= 0.0)
 
-  isStrictlyPositiveReal <- function(o_1_) isPureReal(o_1_) && all(o_1_ > 0.0)
+  isStrictlyPositiveReal <- function(o_1l_) isPureReal(o_1l_) && all(o_1l_ > 0.0)
 
-  isStrictlyNegativeReal <- function(o_1_) isPureReal(o_1_) && all(o_1_ < 0.0)
+  isStrictlyNegativeReal <- function(o_1l_) isPureReal(o_1l_) && all(o_1l_ < 0.0)
 
-  isPositiveInteger <- function(o_1_) isPureMathInteger(o_1_) && all(o_1_ >= 0L)
+  isPositiveInteger <- function(o_1l_) isPureMathInteger(o_1l_) && all(o_1l_ >= 0L)
 
-  isStrictlyPositiveInteger <- function(o_1_) isPureMathInteger(o_1_) && all(o_1_ > 0L)
+  isStrictlyPositiveInteger <- function(o_1l_) isPureMathInteger(o_1l_) && all(o_1l_ > 0L)
 
-  isNegativeInteger <- function(o_1_) isPureMathInteger(o_1_) && all(o_1_ <= 0L)
+  isNegativeInteger <- function(o_1l_) isPureMathInteger(o_1l_) && all(o_1l_ <= 0L)
 
-  isStrictlyNegativeInteger <- function(o_1_) isPureMathInteger(o_1_) && all(o_1_ < 0L)
+  isStrictlyNegativeInteger <- function(o_1l_) isPureMathInteger(o_1l_) && all(o_1l_ < 0L)
 
-  isString <- function(o_1_) {
-    if (!is.character(o_1_)) return(FALSE)
-    if (length(o_1_) == 0) return(TRUE)
-    all(is.na(o_1_) == FALSE)
+  isString <- function(o_1l_) {
+    if (!is.character(o_1l_)) return(FALSE)
+    if (length(o_1l_) == 0) return(TRUE)
+    all(is.na(o_1l_) == FALSE)
   }
 
   allowedSuffixes <- list(
@@ -140,6 +140,8 @@ FunctionParameterTypeFactory <- function() {
 
   addSuffix <- function(suffix_s_1, type_s_1, typeVerifier_f_1) {
     if (!is.function(typeVerifier_f_1)) return(FALSE)
+    i <- identical(retrieveFunctionArguments(isString), retrieveFunctionArguments(typeVerifier_f_1))
+    if (!i) return(FALSE)
     s <- gsub('_*([A-Za-z].*)', '\\1', suffix_s_1, perl = TRUE)
     rv <- checkSuffix(s)
     if (!rv) dt <<- data.table::rbindlist(list(dt, list(s, type_s_1, list(typeVerifier_f_1), type_classes$user_defined)))
@@ -192,32 +194,34 @@ FunctionParameterTypeFactory <- function() {
 
     if (functionParameterName_o$isEllipsis()) return('additional arguments.')
     s <- functionParameterName_o$getTypeSuffix()
-    type <-  if (checkSuffix(s))  {
-      dt[suffix == s]$type
+
+    if (checkSuffix(s))  {
+      type <- dt[suffix == s]$type
+      kind <- if (dt[suffix == s]$category %in% c(type_classes$basic, type_classes$numeric, type_classes$math)) 'values' else 'objects'
     } else {
-      if (functionParameterName_o$isPolymorphic()) 'variable type' else 'unknown'
-    }
-    kind <- if (checkSuffix(s))  {
-      if (dt[suffix == s]$category %in% c(type_classes$basic, type_classes$numeric)) 'values' else 'objects'
-    } else {
-      'objects'
+      type <- if (functionParameterName_o$isPolymorphic()) 'variable type' else 'unknown'
+      kind <- 'objects'
     }
 
     lu <- functionParameterName_o$getLengthSuffix()
     ll <- functionParameterName_o$getLengthModifier()
-    constraint <- if (is.na(lu)) 'unconstrained' else 'constrained'
-    len <- ''
-    if (!is.na(lu)) {
-      tx <- if (!is.na(ll))  {
-        switch(ll, 'n' = paste('1 or', lu), 'l' = paste(lu, 'or less'), 'm' = paste(lu, 'or more'))
+    constraint <- if (is.na(lu)) 'unconstrained' else {
+      if (!is.na(ll))  {
+        paste0('length-',
+               switch(ll, 'n' = paste('1 or', lu), 'l' = paste(lu, 'or less'), 'm' = paste(lu, 'or more'))
+        )
       } else {
-        lu
+        if (lu == 1L) 'single' else paste0('length-', lu)
       }
-      len <- paste0('Vector length must be ', tx ,'.')
     }
 
-    v <- paste0(getAdj(constraint, TRUE), ' ', constraint, ' vector of ', type, ' ', kind, '.')
-    if (len == '') v else paste(v, len)
+    single <- !is.na(lu) && is.na(ll) && lu == 1L
+    paste0(getAdj(constraint, TRUE), ' ', constraint, ' ',
+           if (type == 'list') type else
+             paste0(ifelse(single, '', 'vector of '), type, ' ',
+                    ifelse(single, substr(kind, 1L, nchar(kind) - 1L), kind)
+             )
+    )
   }
 
   self
