@@ -1,4 +1,4 @@
-retrieveFactory <- function(functionParameterTypeFactory_o_1 = NULL) {
+retrieveFactory <- function() {
   v <- Sys.getenv('OP_TYPE_FACTORY')
   if (v != '') {
     g <- tryCatch(get(v, envir = parent.frame()), error = function(e) NA)
