@@ -9,5 +9,5 @@ retrieveFunctionReturnTypes <- function(object_o_1,
                                            functionParameterTypeFactory_o_1)
   if (!v$validity) return(v)
 
-  guardExecution(get(defineFunctionReturnTypesParameterName(), envir = object_o_1))
+  von$sof$instrumented_fn
 }
\ No newline at end of file
